#
# spec file for package yast2-docker
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change spec file in build service directly
#            Use https://github.com/yast/yast-docker repo
#
######################################################################

Name:           yast2-docker
Version:        5.0.0
Release:        1.4
Summary:        YaST2 - GUI for docker management
Group:          System/YaST
License:        GPL-2.0-only OR GPL-3.0-only
URL:            https://github.com/yast/yast-docker

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  update-desktop-files
BuildRequires:  yast2 >= 3.0.5
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-ruby-bindings >= 1.2.0
#for install task
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
# for tests
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
# for docker api
BuildRequires:  rubygem(%{rb_default_ruby_abi}:docker-api)

Requires:       docker >= 1.3
Requires:       yast2 >= 3.1.0
Requires:       yast2-ruby-bindings >= 1.2.0
Requires:       yast2-storage-ng
Requires:       rubygem(%{rb_default_ruby_abi}:docker-api)

BuildArch:      noarch
# ExcludeArch in sync with docker.spec
ExcludeArch:    %ix86 s390 ppc

%description
Provides easy to use GUI for running docker containers.

%prep
%setup -q

%check
%yast_check

%install
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_libdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_icondir}
%license COPYING
%doc README.md

%changelog
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 for openSUSE Leap 15.4 (bsc#1198109)
* Thu May  6 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.1
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Wed Dec 12 2018 jlopez@suse.com
- Hardening commands execution (part of bsc#1118291).
- Replace backticks by Yast::Execute.
- 4.1.1
* Sun Nov 25 2018 Stasiek Michalski <hellcp@mailbox.org>
- Provide icon with module (boo#1109310)
- 4.1.0
* Wed Dec 20 2017 dimstar@opensuse.org
- Add ExcludeArch: %%ix86 s390 ppc: do not build yast2-docker on
  archs where docker is not provided (boo#1073650).
* Fri Nov 17 2017 enavarro@suse.com
- Release 4.0.0
- Fix listing docker images without any tag (bsc#1068688).
* Thu Aug 10 2017 ancor@suse.com
- Use yast2-storage-ng instead of yast2-storage to display the
  size of the images (part of fate#318196).
- 3.3.0
* Mon Mar 13 2017 ancor@suse.com
- Fixed RPM packaging error (bsc#1029088)
- 3.2.0
* Tue Aug  2 2016 mvidner@suse.com
- Declare textdomain to fix untranslated texts in popup dialogs
  (bsc#991753).
- 3.1.8
* Thu Jul 23 2015 jmassaguerpla@suse.com
- Release 3.1.7
  - fix for bsc#938441 - prompt before removing container on stop and kill
* Thu Jun 25 2015 fcastelli@suse.com
- Release 3.1.6
  - ensure untagged images can be removed (bnc#935929)
* Tue Jun 23 2015 fcastelli@suse.com
- Ensure yast2-storage is required at runtime
* Wed May  6 2015 aschnell@suse.de
- Release 3.1.5
  - require rubygems of default ruby version (bsc#929899)
* Fri Apr 10 2015 fcastelli@suse.com
- Release 3.1.4
  - Take advantage of 'docker exec' feature and get rid of nsenter.
* Fri Mar  6 2015 ancor@suse.com
- Release 3.1.3
  - Fixed an error handling the cancel button at the ports and
    volumes pop-up windows (bnc#920638)
* Tue Feb 24 2015 ancor@suse.com
- Release 3.1.2
  - Launching from YaST Control Center works properly (bnc#918758)
* Thu Dec  4 2014 jreidinger@suse.com
- Release 3.3.1:
  - Remove X-KDE-Library from desktop file (bnc#899104)
  - First official version for SLE12 as requested by FATE 317923 and
    by bnc#912733
* Mon Sep 22 2014 jreidinger@suse.com
- initial package
